=============
Django-Twilio
=============

Integrate Twilio into your Django apps with ease.

.. image:: https://badge.fury.io/py/django-twilio.png
    :target: http://badge.fury.io/py/django-twilio
    :alt: PyPI version
.. image:: https://travis-ci.org/rdegges/django-twilio.png?branch=master
    :target: https://travis-ci.org/rdegges/django-twilio
    :alt: CI build
.. image:: https://readthedocs.org/projects/django-twilio/badge/?version=latest
    :target: https://readthedocs.org/projects/django-twilio/badge/?version=latest
    :alt: documentation build
.. image:: https://img.shields.io/pypi/pyversions/django-twilio.svg
    :target:  https://pypi.python.org/pypi/django-twilio/
    :alt: Python versions supported

Meta
----

* Author: Randall Degges
* Email:  rdegges@gmail.com
* Maintainer: Jason Held
* Email: jasonsheld@gmail.com
* Status: active development, stable, maintained

`Twilio <http://www.twilio.com/>`_ is a powerful HTTP API that allows you to
build powerful voice & SMS apps. The goal of this library is to help make
building telephony applications as simple as humanly possible with twilio.


User's Guide
------------


This project aims to keep compatibility with the supported Django releases.

As such our versions of python and django are designed to match that cadence as much as possible.


We are currently compatible with Django 2.2 and 3.0. Python versions 3.5 to 3.8.


This part of the documentation contains an extensive walk through of
django-twilio. It begins with some background information about django-twilio,
then focuses on step-by-step integration of django-twilio into your existing
Django web applications.

.. toctree::
    :maxdepth: 2

    foreword
    install
    settings
    decorators
    requests
    views
    rest
    utils
    gotchas
    howto
    contribute
    contributors


Indices and Tables
------------------

The following is auto-generated documentation that can be used to quickly find
relevant parts of this documentation.

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
